pyexcel.Book
============

.. currentmodule:: pyexcel

.. autoclass:: Book

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Book.__init__
      ~Book.get_array
      ~Book.get_bookdict
      ~Book.get_csv
      ~Book.get_csvz
      ~Book.get_dict
      ~Book.get_fods
      ~Book.get_grid
      ~Book.get_handsontable
      ~Book.get_handsontable_html
      ~Book.get_html
      ~Book.get_json
      ~Book.get_latex
      ~Book.get_latex_booktabs
      ~Book.get_mediawiki
      ~Book.get_ndjson
      ~Book.get_ods
      ~Book.get_orgtbl
      ~Book.get_pipe
      ~Book.get_plain
      ~Book.get_records
      ~Book.get_rst
      ~Book.get_simple
      ~Book.get_svg
      ~Book.get_texttable
      ~Book.get_tsv
      ~Book.get_tsvz
      ~Book.get_url
      ~Book.get_xls
      ~Book.get_xlsm
      ~Book.get_xlsx
      ~Book.init
      ~Book.load_from_sheets
      ~Book.number_of_sheets
      ~Book.plot
      ~Book.register_input
      ~Book.register_io
      ~Book.register_presentation
      ~Book.remove_sheet
      ~Book.save_as
      ~Book.save_to_database
      ~Book.save_to_django_models
      ~Book.save_to_memory
      ~Book.set_array
      ~Book.set_bookdict
      ~Book.set_csv
      ~Book.set_csvz
      ~Book.set_dict
      ~Book.set_fods
      ~Book.set_grid
      ~Book.set_handsontable
      ~Book.set_handsontable_html
      ~Book.set_html
      ~Book.set_json
      ~Book.set_latex
      ~Book.set_latex_booktabs
      ~Book.set_mediawiki
      ~Book.set_ndjson
      ~Book.set_ods
      ~Book.set_orgtbl
      ~Book.set_pipe
      ~Book.set_plain
      ~Book.set_records
      ~Book.set_rst
      ~Book.set_simple
      ~Book.set_svg
      ~Book.set_texttable
      ~Book.set_tsv
      ~Book.set_tsvz
      ~Book.set_url
      ~Book.set_xls
      ~Book.set_xlsm
      ~Book.set_xlsx
      ~Book.sheet_by_index
      ~Book.sheet_by_name
      ~Book.sheet_names
      ~Book.sort_sheets
      ~Book.to_dict
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Book.array
      ~Book.bookdict
      ~Book.csv
      ~Book.csvz
      ~Book.dict
      ~Book.fods
      ~Book.grid
      ~Book.handsontable
      ~Book.handsontable_html
      ~Book.html
      ~Book.json
      ~Book.latex
      ~Book.latex_booktabs
      ~Book.mediawiki
      ~Book.ndjson
      ~Book.ods
      ~Book.orgtbl
      ~Book.pipe
      ~Book.plain
      ~Book.records
      ~Book.rst
      ~Book.simple
      ~Book.stream
      ~Book.svg
      ~Book.texttable
      ~Book.tsv
      ~Book.tsvz
      ~Book.url
      ~Book.xls
      ~Book.xlsm
      ~Book.xlsx
   
   